@@ -2,7 +2,7 @@ package Test2::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000081'; # TRIAL
+our $VERSION = '0.000085'; # TRIAL
 
 use Scalar::Util qw/blessed/;
 use Test2::Util qw/try/;
@@ -118,7 +118,7 @@ sub _convert {
     return Test2::Compare::Undef->new()
         unless defined $thing;
 
-    if ($thing && blessed($thing) && $thing->isa('Test2::Compare::Base')) {
+    if (blessed($thing) && $thing->isa('Test2::Compare::Base')) {
         if ($config->{implicit_end} && $thing->can('set_ending') && !defined $thing->ending) {
             my $clone = $thing->clone;
             $clone->set_ending('implicit');
@@ -439,7 +439,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
