@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000081'; # TRIAL
+our $VERSION = '0.000085'; # TRIAL
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -202,7 +202,7 @@ sub D() {
 sub DF() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { defined $_ && ! $_ ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
+        code => sub { defined $_ && ( ! ref $_ && ! $_ ) ? 1 : 0 }, name => 'DEFINED BUT FALSE', operator => 'DEFINED() && FALSE()',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -238,7 +238,7 @@ sub F() {
 sub FDNE() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { $_ ? 0 : 1 }, name => 'FALSE', operator => 'FALSE() || !exists',
+        code => sub { defined $_ && ( ref $_ || $_ ) ? 0 : 1 }, name => 'FALSE', operator => 'FALSE() || !exists',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -247,7 +247,7 @@ sub FDNE() {
 sub T() {
     my @caller = caller;
     Test2::Compare::Custom->new(
-        code => sub { $_ ? 1 : 0 }, name => 'TRUE', operator => 'TRUE()',
+        code => sub { defined $_ && ( ref $_ || $_ ) ? 1 : 0 }, name => 'TRUE', operator => 'TRUE()',
         file => $caller[1],
         lines => [$caller[2]],
     );
@@ -341,7 +341,7 @@ sub string($;@) {
 }
 
 sub filter_items(&) {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support filters"
         unless $build->can('add_filter');
@@ -353,7 +353,7 @@ sub filter_items(&) {
 }
 
 sub all_items {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support all-items"
         unless $build->can('add_for_each');
@@ -365,7 +365,7 @@ sub all_items {
 }
 
 sub all_keys {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support all-keys"
         unless $build->can('add_for_each_key');
@@ -378,7 +378,7 @@ sub all_keys {
 
 *all_vals = *all_values;
 sub all_values {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support all-values"
         unless $build->can('add_for_each_val');
@@ -391,7 +391,7 @@ sub all_values {
 
 
 sub end() {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support 'ending'"
         unless $build->can('ending');
@@ -403,7 +403,7 @@ sub end() {
 }
 
 sub etc() {
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support 'ending'"
         unless $build->can('ending');
@@ -416,7 +416,7 @@ sub etc() {
 
 my $_call = sub {
     my ($name, $expect, $context, $func_name) = @_;
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support method calls"
         unless $build->can('add_call');
@@ -443,7 +443,7 @@ sub call_hash($$) { $_call->(@_,'hash','call_hash') }
 
 sub prop($$) {
     my ($name, $expect) = @_;
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support meta-checks"
         unless $build->can('add_prop');
@@ -466,7 +466,7 @@ sub item($;$) {
     my @args   = @_;
     my $expect = pop @args;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support array item checks"
         unless $build->can('add_item');
@@ -487,7 +487,7 @@ sub item($;$) {
 sub field($$) {
     my ($name, $expect) = @_;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' does not support hash field checks"
         unless $build->can('add_field');
@@ -509,7 +509,7 @@ sub field($$) {
 sub check($) {
     my ($check) = @_;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
 
     croak "'$build' is not a check-set"
         unless $build->can('add_check');
@@ -556,7 +556,7 @@ sub fail_events($;$) {
 
     return ($event, $diag) if defined wantarray;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
     $build->add_item($event);
     $build->add_item($diag);
 }
@@ -613,7 +613,7 @@ sub event($;$) {
 
     return $event if defined wantarray;
 
-    my $build = get_build() or croak "No current build!";
+    defined( my $build = get_build() ) or croak "No current build!";
     $build->add_item($event);
 }
 
@@ -1684,7 +1684,7 @@ F<http://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
